@@ -8,6 +8,13 @@ import logging
 
 import requests
 
+from .exceptions import (
+    InternalServerError,
+    NotFoundError,
+    UnauthorizedError,
+    UnexpectedError,
+)
+
 API_HOST = "https://api.danfoss.com"
 
 _LOGGER = logging.getLogger(__name__)
@@ -32,26 +39,35 @@ class DanfossAllyAPI:
 
         try:
             if payload:
+                _LOGGER.debug("Send command: %s: %s", path, json.dumps(payload))
                 req = requests.post(
                     API_HOST + path, json=payload, headers=headers_data, timeout=10
                 )
             else:
                 req = requests.get(API_HOST + path, headers=headers_data, timeout=10)
 
-            if not req.ok:
-                return False
+            req.raise_for_status()
+        except requests.exceptions.HTTPError as err:
+            code = err.response.status_code
+            if payload:
+                _LOGGER.debug("Http status code: %s", code)
+            if code == 401:
+                raise UnauthorizedError
+            if code == 404:
+                raise NotFoundError
+            if code == 500:
+                raise InternalServerError
+            return False
         except TimeoutError:
-            _LOGGER.warning("Timeout communication with Danfoss Ally API")
-            return False
+            raise TimeoutError
         except:
-            _LOGGER.warning(
-                "Unexpected error occured in communications with Danfoss Ally API!"
-            )
-            return False
+            raise UnexpectedError
 
-        json = req.json()
-        print("JSON: ", json)
-        return json
+        response = req.json()
+        if payload:
+            _LOGGER.debug("Command response: %s", response)
+        print("JSON: ", response)
+        return response
 
     def _refresh_token(self) -> bool:
         """Refresh OAuth2 token if expired."""
@@ -165,6 +181,22 @@ class DanfossAllyAPI:
 
         return callData["result"]
 
+
+    def send_command(self, device_id: str, listofcommands: list[Tuple[str, str]]) -> bool:
+        """Send commands."""
+
+        commands = []
+        for code,value in listofcommands:
+            commands += [{"code": code, "value": value}]
+        request_body = {"commands": commands}
+
+        callData = self._call(
+            "/ally/devices/" + device_id + "/commands", payload=request_body
+        )
+
+        return callData["result"]
+
+
     @property
     def token(self) -> str:
         """Return token."""
